aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/Ryujinx.Graphics.Vulkan/PipelineState.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Ryujinx.Graphics.Vulkan/PipelineState.cs b/src/Ryujinx.Graphics.Vulkan/PipelineState.cs
index 21160858..c3874893 100644
--- a/src/Ryujinx.Graphics.Vulkan/PipelineState.cs
+++ b/src/Ryujinx.Graphics.Vulkan/PipelineState.cs
@@ -560,9 +560,9 @@ namespace Ryujinx.Graphics.Vulkan
}
}
// AMD has a bug where it enables logical operations even for float formats,
// so we need to force disable them here.
- bool logicOpEnable = LogicOpEnable && (gd.Vendor != Vendor.Amd || Internal.LogicOpsAllowed);
+ bool logicOpEnable = LogicOpEnable && (gd.Vendor == Vendor.Nvidia || Internal.LogicOpsAllowed);
var colorBlendState = new PipelineColorBlendStateCreateInfo
{
@@ -560,9 +560,9 @@ namespace Ryujinx.Graphics.Vulkan
}
}
- // AMD has a bug where it enables logical operations even for float formats,
+ // Vendors other than NVIDIA have a bug where it enables logical operations even for float formats,
// so we need to force disable them here.